Request

#[non_exhaustive]
pub enum Request<'a> { Destroy, GetBackgroundEffect { surface: WlSurface, }, }

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Destroy

destroy the background effect manager

Informs the server that the client will no longer be using this protocol object. Existing objects created by this object are not affected.

This is a destructor, once sent this object cannot be used any longer.



GetBackgroundEffect

get a background effects object

Instantiate an interface extension for the given wl_surface to add effects like blur for the background behind it.

If the given wl_surface already has a ext_background_effect_surface_v1 object associated, the background_effect_exists protocol error will be raised.

Fields

surface: WlSurface

the surface

Implementations

Source

impl<'a> Request<'a>

pub fn opcode(&self) -> u16

Get the opcode number of this message