pub struct ExtBackgroundEffectManagerV1 { /* private fields */ }Expand description
background effect factory
This protocol provides a way to improve visuals of translucent surfaces by applying effects like blur to the background behind them.
The capabilities are send when the global is bound, and every time they change. Note that when the capability goes away, the corresponding effect is no longer applied by the compositor, even if it was set before.
Warning! The protocol described in this file is currently in the testing phase. Backward compatible changes may be added together with the corresponding interface version bump. Backward incompatible changes can only be done by creating a new major version of the extension.
See also the Event enum for this interface.
Implementations
Sourceimpl ExtBackgroundEffectManagerV1
impl ExtBackgroundEffectManagerV1
Sourcepub fn destroy(&self)
pub fn destroy(&self)
destroy the background effect manager
Informs the server that the client will no longer be using this protocol object. Existing objects created by this object are not affected.
Sourcepub fn get_background_effect<U, D: 'static>(
&self,
surface: &WlSurface,
qh: &QueueHandle<D>,
udata: U,
) -> ExtBackgroundEffectSurfaceV1
pub fn get_background_effect<U, D: 'static>( &self, surface: &WlSurface, qh: &QueueHandle<D>, udata: U, ) -> ExtBackgroundEffectSurfaceV1
get a background effects object
Instantiate an interface extension for the given wl_surface to add effects like blur for the background behind it.
If the given wl_surface already has a ext_background_effect_surface_v1 object associated, the background_effect_exists protocol error will be raised.